@@ -53,14 +53,14 @@ Smb4KNetworkBrowser::Smb4KNetworkBrowser( TQWidget *parent, const char *name )
   addColumn( i18n( "Comment" ), -1 );
 
   // Add some connections:
-  connect( this, TQT_SIGNAL( expanded( TQListViewItem * ) ),
-           this, TQT_SLOT( slotItemExpandedCollapsed( TQListViewItem * ) ) );
+  connect( this, TQ_SIGNAL( expanded( TQListViewItem * ) ),
+           this, TQ_SLOT( slotItemExpandedCollapsed( TQListViewItem * ) ) );
 
-  connect( this, TQT_SIGNAL( collapsed( TQListViewItem * ) ),
-           this, TQT_SLOT( slotItemExpandedCollapsed( TQListViewItem * ) ) );
+  connect( this, TQ_SIGNAL( collapsed( TQListViewItem * ) ),
+           this, TQ_SLOT( slotItemExpandedCollapsed( TQListViewItem * ) ) );
 
-  connect( this, TQT_SIGNAL( executed( TQListViewItem * ) ),
-           this, TQT_SLOT( slotItemExecuted( TQListViewItem * ) ) );
+  connect( this, TQ_SIGNAL( executed( TQListViewItem * ) ),
+           this, TQ_SLOT( slotItemExecuted( TQListViewItem * ) ) );
 }
 
 
@@ -114,7 +114,7 @@ void Smb4KNetworkBrowser::contentsMouseMoveEvent( TQMouseEvent *e )
           {
             m_tooltip = new Smb4KNetworkBrowserToolTip( item );
 
-            TQTimer::singleShot( 2000, this, TQT_SLOT( slotShowToolTip() ) );
+            TQTimer::singleShot( 2000, this, TQ_SLOT( slotShowToolTip() ) );
           }
           else
           {
@@ -133,7 +133,7 @@ void Smb4KNetworkBrowser::contentsMouseMoveEvent( TQMouseEvent *e )
         {
           m_tooltip = new Smb4KNetworkBrowserToolTip( item );
 
-          TQTimer::singleShot( 2000, this, TQT_SLOT( slotShowToolTip() ) );
+          TQTimer::singleShot( 2000, this, TQ_SLOT( slotShowToolTip() ) );
         }
         else
         {
@@ -161,7 +161,7 @@ void Smb4KNetworkBrowser::contentsMouseMoveEvent( TQMouseEvent *e )
 
 
 /////////////////////////////////////////////////////////////////////////////
-// TQT_SLOT IMPLEMENTATIONS
+// SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
 
 void Smb4KNetworkBrowser::slotItemExpandedCollapsed( TQListViewItem *item )
