@@ -96,7 +96,7 @@ void Smb4KNetworkBrowserToolTip::showTip( const TQPoint &pos )
   setGeometry( p.x(), p.y(), width(), height() );
   polish();
   show();
-  TQTimer::singleShot( 10000, this, TQT_SLOT( slotHideToolTip() ) );
+  TQTimer::singleShot( 10000, this, TQ_SLOT( slotHideToolTip() ) );
 }
 
 
@@ -267,7 +267,7 @@ void Smb4KNetworkBrowserToolTip::update()
   {
     case Smb4KNetworkBrowserItem::Workgroup:
     {
-      TQLabel *master_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "MasterBrowser", TQLABEL_OBJECT_NAME_STRING, true )) );
+      TQLabel *master_label = static_cast<TQLabel *>( child( "MasterBrowser", "TQLabel", true ) );
 
       if ( master_label )
       {
@@ -282,9 +282,9 @@ void Smb4KNetworkBrowserToolTip::update()
     }
     case Smb4KNetworkBrowserItem::Host:
     {
-      TQLabel *os_label =     static_cast<TQLabel *>( TQT_TQWIDGET(child( "OSString", TQLABEL_OBJECT_NAME_STRING, true )) );
-      TQLabel *server_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "ServerString", TQLABEL_OBJECT_NAME_STRING, true )) );
-      TQLabel *ip_label =     static_cast<TQLabel *>( TQT_TQWIDGET(child( "IPAddress", TQLABEL_OBJECT_NAME_STRING, true )) );
+      TQLabel *os_label =     static_cast<TQLabel *>( child( "OSString", "TQLabel", true ) );
+      TQLabel *server_label = static_cast<TQLabel *>( child( "ServerString", "TQLabel", true ) );
+      TQLabel *ip_label =     static_cast<TQLabel *>( child( "IPAddress", "TQLabel", true ) );
 
       if ( os_label )
       {
@@ -317,7 +317,7 @@ void Smb4KNetworkBrowserToolTip::update()
     }
     case Smb4KNetworkBrowserItem::Share:
     {
-      TQLabel *ip_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "IPAddress", TQLABEL_OBJECT_NAME_STRING, true )) );
+      TQLabel *ip_label = static_cast<TQLabel *>( child( "IPAddress", "TQLabel", true ) );
 
       if ( ip_label )
       {
@@ -363,7 +363,7 @@ void Smb4KNetworkBrowserToolTip::leaveEvent( TQEvent *e )
 
 
 /////////////////////////////////////////////////////////////////////////////
-// TQT_SLOT IMPLEMENTATIONS
+// SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
 
 void Smb4KNetworkBrowserToolTip::slotHideToolTip()
