@@ -45,7 +45,7 @@
 
 class Smb4KAuthOptions : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
