@@ -48,7 +48,7 @@ Smb4KSuperUserOptions::Smb4KSuperUserOptions( TQWidget *parent, const char *name
   TQGridLayout *grid =           new TQGridLayout( this );
   grid->setSpacing( 10 );
 
-  TQButtonGroup *suid_progs =    new TQButtonGroup( 1, Qt::Horizontal,
+  TQButtonGroup *suid_progs =    new TQButtonGroup( 1, TQt::Horizontal,
                                 i18n( "Programs" ), this, "kcfg_SuperUserProgram" );
   suid_progs->setInsideSpacing( 5 );
 
@@ -56,7 +56,7 @@ Smb4KSuperUserOptions::Smb4KSuperUserOptions( TQWidget *parent, const char *name
   suid_progs->insert( new TQRadioButton( "sudo", suid_progs, "SudoButton" ), Smb4KSettings::EnumSuperUserProgram::Sudo );
   suid_progs->insert( new TQRadioButton( "super", suid_progs, "SuperButton" ), Smb4KSettings::EnumSuperUserProgram::Super );
 
-  TQButtonGroup *suid_actions =  new TQButtonGroup( 1, Qt::Horizontal, i18n( "Actions" ), this, "SUIDActions" );
+  TQButtonGroup *suid_actions =  new TQButtonGroup( 1, TQt::Horizontal, i18n( "Actions" ), this, "SUIDActions" );
   suid_actions->setInsideSpacing( 5 );
 #ifdef __linux__
   (void) new TQCheckBox( i18n( "Use super user privileges to force the unmounting of (inaccessible) shares" ), suid_actions, "kcfg_UseForceUnmount" );
@@ -77,8 +77,8 @@ Smb4KSuperUserOptions::Smb4KSuperUserOptions( TQWidget *parent, const char *name
   grid->addWidget( remove, 2, 3, 0 );
   grid->addMultiCell( spacer2, 3, 3, 0, 3, 0 );
 
-  connect( remove, TQT_SIGNAL( clicked() ),
-           this,   TQT_SLOT( slotRemoveClicked() ) );
+  connect( remove, TQ_SIGNAL( clicked() ),
+           this,   TQ_SLOT( slotRemoveClicked() ) );
 }
 
 
@@ -88,7 +88,7 @@ Smb4KSuperUserOptions::~Smb4KSuperUserOptions()
 
 
 /////////////////////////////////////////////////////////////////////////////
-// TQT_SLOT IMPLEMENTATIONS
+// SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
 
 void Smb4KSuperUserOptions::slotRemoveClicked()
