@@ -52,7 +52,7 @@ Smb4KRsyncOptions::Smb4KRsyncOptions( TQWidget *parent, const char *name ) : TQT
   TQGridLayout *copying_layout = new TQGridLayout( copying_tab );
   copying_layout->setSpacing( 10 );
 
-  TQGroupBox *directory_box = new TQGroupBox( 2, Qt::Horizontal, i18n( "Default Destination" ),
+  TQGroupBox *directory_box = new TQGroupBox( 2, TQt::Horizontal, i18n( "Default Destination" ),
                              copying_tab, "RsyncDestinationBox" );
   directory_box->setInsideSpacing( 5 );
 
@@ -60,7 +60,7 @@ Smb4KRsyncOptions::Smb4KRsyncOptions( TQWidget *parent, const char *name ) : TQT
   KURLRequester *prefix = new KURLRequester( directory_box, "kcfg_RsyncPrefix" );
   prefix->setMode( KFile::Directory | KFile::LocalOnly );
 
-  TQButtonGroup *general_box = new TQButtonGroup( 2, Qt::Horizontal, i18n( "General" ),
+  TQButtonGroup *general_box = new TQButtonGroup( 2, TQt::Horizontal, i18n( "General" ),
                               copying_tab, "RsyncModeBox" );
   general_box->setInsideSpacing( 5 );
 
@@ -73,7 +73,7 @@ Smb4KRsyncOptions::Smb4KRsyncOptions( TQWidget *parent, const char *name ) : TQT
   (void) new TQCheckBox( i18n( "Transfer directories without recursing" ), general_box, "kcfg_TransferDirectories" );
   (void) new TQCheckBox( i18n( "Compress data during transfer" ), general_box, "kcfg_CompressData" );
 
-  TQButtonGroup *links_box = new TQButtonGroup( 2, Qt::Horizontal, i18n( "Links" ), copying_tab, "RsyncModeBox" );
+  TQButtonGroup *links_box = new TQButtonGroup( 2, TQt::Horizontal, i18n( "Links" ), copying_tab, "RsyncModeBox" );
   links_box->setInsideSpacing( 5 );
 
   TQCheckBox *links = new TQCheckBox( i18n( "Preserve symlinks" ), links_box, "kcfg_PreserveSymlinks" );
@@ -83,7 +83,7 @@ Smb4KRsyncOptions::Smb4KRsyncOptions( TQWidget *parent, const char *name ) : TQT
   (void) new TQCheckBox( i18n( "Preserve hard links" ), links_box, "kcfg_PreserveHardLinks" );
   (void) new TQCheckBox( i18n( "Keep directory symlinks" ), links_box, "kcfg_KeepDirectorySymlinks" );
 
-  TQButtonGroup *perm_box = new TQButtonGroup( 2, Qt::Horizontal, i18n( "File Permissions, etc." ),
+  TQButtonGroup *perm_box = new TQButtonGroup( 2, TQt::Horizontal, i18n( "File Permissions, etc." ),
                            copying_tab, "RsyncPreservationBox" );
   perm_box->setInsideSpacing( 5 );
 
@@ -112,7 +112,7 @@ Smb4KRsyncOptions::Smb4KRsyncOptions( TQWidget *parent, const char *name ) : TQT
   TQGridLayout *deltrans_layout = new TQGridLayout( deltrans_tab );
   deltrans_layout->setSpacing( 10 );
 
-  TQButtonGroup *delete_box = new TQButtonGroup( 2, Qt::Horizontal, i18n( "File Deletion" ), deltrans_tab, "RsyncDeleteBox" );
+  TQButtonGroup *delete_box = new TQButtonGroup( 2, TQt::Horizontal, i18n( "File Deletion" ), deltrans_tab, "RsyncDeleteBox" );
   delete_box->setInsideSpacing( 5 );
 
   (void) new TQCheckBox( i18n( "Remove synchronized source files" ), delete_box, "kcfg_RemoveSourceFiles" );
@@ -124,13 +124,13 @@ Smb4KRsyncOptions::Smb4KRsyncOptions( TQWidget *parent, const char *name ) : TQT
   (void) new TQCheckBox( i18n( "Delete even if I/O errors occur" ), delete_box, "kcfg_IgnoreErrors" );
   (void) new TQCheckBox( i18n( "Force deletion of non-void directories" ), delete_box, "kcfg_ForceDirectoryDeletion" );
 
-  TQButtonGroup *delete_restrictions_box = new TQButtonGroup( 2, Qt::Horizontal, i18n( "Restrictions" ), deltrans_tab, "RsyncDeleteRestrictionsBox" );
+  TQButtonGroup *delete_restrictions_box = new TQButtonGroup( 2, TQt::Horizontal, i18n( "Restrictions" ), deltrans_tab, "RsyncDeleteRestrictionsBox" );
   delete_restrictions_box->setInsideSpacing( 5 );
 
   (void) new TQCheckBox( i18n( "Don't delete more than this many files:" ), delete_restrictions_box, "kcfg_UseMaximumDelete" );
   (void) new KIntNumInput( delete_restrictions_box, "kcfg_MaximumDeleteValue" );
 
-  TQButtonGroup *transfer_box = new TQButtonGroup( 2, Qt::Horizontal, i18n( "File Transfer" ),
+  TQButtonGroup *transfer_box = new TQButtonGroup( 2, TQt::Horizontal, i18n( "File Transfer" ),
                                deltrans_tab, "RsyncFileTransferBox" );
   transfer_box->setInsideSpacing( 5 );
 
@@ -163,7 +163,7 @@ Smb4KRsyncOptions::Smb4KRsyncOptions( TQWidget *parent, const char *name ) : TQT
   TQGridLayout *filter_layout = new TQGridLayout( filter_tab );
   filter_layout->setSpacing( 10 );
 
-  TQButtonGroup *general_filter_box = new TQButtonGroup( 2, Qt::Horizontal, i18n( "General" ),
+  TQButtonGroup *general_filter_box = new TQButtonGroup( 2, TQt::Horizontal, i18n( "General" ),
                                      filter_tab, "RsyncGeneralFilterBox" );
   general_filter_box->setInsideSpacing( 5 );
 
@@ -180,7 +180,7 @@ Smb4KRsyncOptions::Smb4KRsyncOptions( TQWidget *parent, const char *name ) : TQT
   KURLRequester *include_from = new KURLRequester( general_filter_box, "kcfg_IncludeFrom" );
   include_from->setMode( KFile::File | KFile::LocalOnly );
 
-  TQButtonGroup *filter_rules_box = new TQButtonGroup( 1, Qt::Horizontal, i18n( "Filter Rules" ),
+  TQButtonGroup *filter_rules_box = new TQButtonGroup( 1, TQt::Horizontal, i18n( "Filter Rules" ),
                                    filter_tab, "RsyncFilterRulesBox" );
   filter_rules_box->setInsideSpacing( 5 );
   TQLabel *filter_rules_label = new TQLabel( i18n( "The rules defined below will be added to the \"rsync\" command as they are. Thus, you have to start with the --filter=... argument." ), filter_rules_box );
@@ -206,7 +206,7 @@ Smb4KRsyncOptions::Smb4KRsyncOptions( TQWidget *parent, const char *name ) : TQT
   TQGridLayout *advanced_layout = new TQGridLayout( advanced_tab );
   advanced_layout->setSpacing( 10 );
 
-  TQButtonGroup *misc_box = new TQButtonGroup( 2, Qt::Horizontal, i18n( "General" ),
+  TQButtonGroup *misc_box = new TQButtonGroup( 2, TQt::Horizontal, i18n( "General" ),
                            advanced_tab, "RsyncAdvancedMiscBox" );
   misc_box->setInsideSpacing( 5 );
 
@@ -217,7 +217,7 @@ Smb4KRsyncOptions::Smb4KRsyncOptions( TQWidget *parent, const char *name ) : TQT
   (void) new TQCheckBox( i18n( "Ignore files that already exist" ), misc_box, "kcfg_IgnoreExisting" );
   (void) new TQCheckBox( i18n( "Delay updates until the end of transfer" ), misc_box, "kcfg_DelayUpdates" );
 
-  TQButtonGroup *backup_box = new TQButtonGroup( 2, Qt::Horizontal, i18n( "Backup" ), advanced_tab, "RsyncBackupBox" );
+  TQButtonGroup *backup_box = new TQButtonGroup( 2, TQt::Horizontal, i18n( "Backup" ), advanced_tab, "RsyncBackupBox" );
   backup_box->setInsideSpacing( 5 );
 
   TQCheckBox *backup = new TQCheckBox( i18n( "Make backups" ), backup_box, "kcfg_MakeBackups" );
@@ -228,7 +228,7 @@ Smb4KRsyncOptions::Smb4KRsyncOptions( TQWidget *parent, const char *name ) : TQT
   KURLRequester *backup_dir = new KURLRequester( backup_box, "kcfg_BackupDirectory" );
   backup_dir->setMode( KFile::Directory | KFile::LocalOnly );
 
-  TQButtonGroup *checksum_box = new TQButtonGroup( 2, Qt::Horizontal, i18n( "Checksums" ), advanced_tab, "RsyncChecksumsBox" );
+  TQButtonGroup *checksum_box = new TQButtonGroup( 2, TQt::Horizontal, i18n( "Checksums" ), advanced_tab, "RsyncChecksumsBox" );
   checksum_box->setInsideSpacing( 5 );
 
   (void) new TQCheckBox( i18n( "Force fixed checksum block size:" ), checksum_box, "kcfg_UseBlockSize" );
@@ -247,38 +247,38 @@ Smb4KRsyncOptions::Smb4KRsyncOptions( TQWidget *parent, const char *name ) : TQT
 
   addTab( advanced_tab, i18n( "Advanced" ) );
 
-  connect( archive_mode, TQT_SIGNAL( toggled( bool ) ),
-           this,         TQT_SLOT( slotArchiveToggled( bool ) ) );
+  connect( archive_mode, TQ_SIGNAL( toggled( bool ) ),
+           this,         TQ_SLOT( slotArchiveToggled( bool ) ) );
 
-  connect( recursive,    TQT_SIGNAL( toggled( bool ) ),
-           this,         TQT_SLOT( slotUncheckArchive( bool ) ) );
+  connect( recursive,    TQ_SIGNAL( toggled( bool ) ),
+           this,         TQ_SLOT( slotUncheckArchive( bool ) ) );
 
-  connect( links,        TQT_SIGNAL( toggled( bool ) ),
-           this,         TQT_SLOT( slotUncheckArchive( bool ) ) );
+  connect( links,        TQ_SIGNAL( toggled( bool ) ),
+           this,         TQ_SLOT( slotUncheckArchive( bool ) ) );
 
-  connect( perms,        TQT_SIGNAL( toggled( bool ) ),
-           this,         TQT_SLOT( slotUncheckArchive( bool ) ) );
+  connect( perms,        TQ_SIGNAL( toggled( bool ) ),
+           this,         TQ_SLOT( slotUncheckArchive( bool ) ) );
 
-  connect( times,        TQT_SIGNAL( toggled( bool ) ),
-           this,         TQT_SLOT( slotUncheckArchive( bool ) ) );
+  connect( times,        TQ_SIGNAL( toggled( bool ) ),
+           this,         TQ_SLOT( slotUncheckArchive( bool ) ) );
 
-  connect( group,        TQT_SIGNAL( toggled( bool ) ),
-           this,         TQT_SLOT( slotUncheckArchive( bool ) ) );
+  connect( group,        TQ_SIGNAL( toggled( bool ) ),
+           this,         TQ_SLOT( slotUncheckArchive( bool ) ) );
 
-  connect( owner,        TQT_SIGNAL( toggled( bool ) ),
-           this,         TQT_SLOT( slotUncheckArchive( bool ) ) );
+  connect( owner,        TQ_SIGNAL( toggled( bool ) ),
+           this,         TQ_SLOT( slotUncheckArchive( bool ) ) );
 
-  connect( devices,      TQT_SIGNAL( toggled( bool ) ),
-           this,         TQT_SLOT( slotUncheckArchive( bool ) ) );
+  connect( devices,      TQ_SIGNAL( toggled( bool ) ),
+           this,         TQ_SLOT( slotUncheckArchive( bool ) ) );
 
-  connect( backup,       TQT_SIGNAL( toggled( bool ) ),
-           this,         TQT_SLOT( slotBackupToggled( bool ) ) );
+  connect( backup,       TQ_SIGNAL( toggled( bool ) ),
+           this,         TQ_SLOT( slotBackupToggled( bool ) ) );
 
-  connect( f_filter,     TQT_SIGNAL( toggled( bool ) ),
-           this,         TQT_SLOT( slotFShortcutToggled( bool ) ) );
+  connect( f_filter,     TQ_SIGNAL( toggled( bool ) ),
+           this,         TQ_SLOT( slotFShortcutToggled( bool ) ) );
 
-  connect( ff_filter,    TQT_SIGNAL( toggled( bool ) ),
-           this,         TQT_SLOT( slotFFShortcutToggled( bool ) ) );
+  connect( ff_filter,    TQ_SIGNAL( toggled( bool ) ),
+           this,         TQ_SLOT( slotFFShortcutToggled( bool ) ) );
 
   slotArchiveToggled( true );
   slotBackupToggled( false );
@@ -291,20 +291,20 @@ Smb4KRsyncOptions::~Smb4KRsyncOptions()
 
 
 /////////////////////////////////////////////////////////////////////////////
-// TQT_SLOT IMPLEMENTATIONS
+// SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
 
 void Smb4KRsyncOptions::slotArchiveToggled( bool on )
 {
   if ( on )
   {
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_RecurseIntoDirectories", "TQCheckBox", true )) )->setChecked( on );
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreserveSymlinks", "TQCheckBox", true )) )->setChecked( on );
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreservePermissions", "TQCheckBox", true )) )->setChecked( on );
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreserveTimes", "TQCheckBox", true )) )->setChecked( on );
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreserveGroup", "TQCheckBox", true )) )->setChecked( on );
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreserveOwner", "TQCheckBox", true )) )->setChecked( on );
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_PreserveDevicesAndSpecials", "TQCheckBox", true )) )->setChecked( on );
+    static_cast<TQCheckBox *>( child( "kcfg_RecurseIntoDirectories", "TQCheckBox", true ) )->setChecked( on );
+    static_cast<TQCheckBox *>( child( "kcfg_PreserveSymlinks", "TQCheckBox", true ) )->setChecked( on );
+    static_cast<TQCheckBox *>( child( "kcfg_PreservePermissions", "TQCheckBox", true ) )->setChecked( on );
+    static_cast<TQCheckBox *>( child( "kcfg_PreserveTimes", "TQCheckBox", true ) )->setChecked( on );
+    static_cast<TQCheckBox *>( child( "kcfg_PreserveGroup", "TQCheckBox", true ) )->setChecked( on );
+    static_cast<TQCheckBox *>( child( "kcfg_PreserveOwner", "TQCheckBox", true ) )->setChecked( on );
+    static_cast<TQCheckBox *>( child( "kcfg_PreserveDevicesAndSpecials", "TQCheckBox", true ) )->setChecked( on );
   }
 }
 
@@ -313,23 +313,23 @@ void Smb4KRsyncOptions::slotUncheckArchive( bool on )
 {
   if ( !on )
   {
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_ArchiveMode", "TQCheckBox", true )) )->setChecked( on );
+    static_cast<TQCheckBox *>( child( "kcfg_ArchiveMode", "TQCheckBox", true ) )->setChecked( on );
   }
 }
 
 
 void Smb4KRsyncOptions::slotBackupToggled( bool on )
 {
-  static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_UseBackupDirectory", "TQCheckBox", true )) )->setEnabled( on );
-  static_cast<KURLRequester *>( TQT_TQWIDGET(child( "kcfg_BackupDirectory", "KURLRequester", true )) )->setEnabled( on );
-  static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_UseBackupSuffix", "TQCheckBox", true )) )->setEnabled( on );
-  static_cast<KLineEdit *>( TQT_TQWIDGET(child( "kcfg_BackupSuffix", "KLineEdit", true )) )->setEnabled( on );
+  static_cast<TQCheckBox *>( child( "kcfg_UseBackupDirectory", "TQCheckBox", true ) )->setEnabled( on );
+  static_cast<KURLRequester *>( child( "kcfg_BackupDirectory", "KURLRequester", true ) )->setEnabled( on );
+  static_cast<TQCheckBox *>( child( "kcfg_UseBackupSuffix", "TQCheckBox", true ) )->setEnabled( on );
+  static_cast<KLineEdit *>( child( "kcfg_BackupSuffix", "KLineEdit", true ) )->setEnabled( on );
 }
 
 
 void Smb4KRsyncOptions::slotFShortcutToggled( bool on )
 {
-  TQCheckBox *ff_filter = static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_UseFFFilterRule", "TQCheckBox", true )) );
+  TQCheckBox *ff_filter = static_cast<TQCheckBox *>( child( "kcfg_UseFFFilterRule", "TQCheckBox", true ) );
 
   if ( on && ff_filter->isChecked() )
   {
@@ -340,7 +340,7 @@ void Smb4KRsyncOptions::slotFShortcutToggled( bool on )
 
 void Smb4KRsyncOptions::slotFFShortcutToggled( bool on )
 {
-  TQCheckBox *f_filter = static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_UseFFilterRule", "TQCheckBox", true )) );
+  TQCheckBox *f_filter = static_cast<TQCheckBox *>( child( "kcfg_UseFFilterRule", "TQCheckBox", true ) );
 
   if ( on && f_filter->isChecked() )
   {
