@@ -83,23 +83,23 @@ Smb4KCore::Smb4KCore() : TQObject()
   m_previewer_state = PREVIEWER_STOP;
 
   // Connections:
-  connect( m_scanner,         TQT_SIGNAL( state( int ) ),
-           this,              TQT_SLOT( slotSetScannerState( int ) ) );
+  connect( m_scanner,         TQ_SIGNAL( state( int ) ),
+           this,              TQ_SLOT( slotSetScannerState( int ) ) );
 
-  connect( m_mounter,         TQT_SIGNAL( state( int ) ),
-           this,              TQT_SLOT( slotSetMounterState( int ) ) );
+  connect( m_mounter,         TQ_SIGNAL( state( int ) ),
+           this,              TQ_SLOT( slotSetMounterState( int ) ) );
 
-  connect( m_print,           TQT_SIGNAL( state( int ) ),
-           this,              TQT_SLOT( slotSetPrinterHandlerState( int ) ) );
+  connect( m_print,           TQ_SIGNAL( state( int ) ),
+           this,              TQ_SLOT( slotSetPrinterHandlerState( int ) ) );
 
-  connect( m_synchronizer,    TQT_SIGNAL( state( int ) ),
-           this,              TQT_SLOT( slotSetSynchronizerState( int ) ) );
+  connect( m_synchronizer,    TQ_SIGNAL( state( int ) ),
+           this,              TQ_SLOT( slotSetSynchronizerState( int ) ) );
 
-  connect( m_previewer,       TQT_SIGNAL( state( int ) ),
-           this,              TQT_SLOT( slotSetSynchronizerState( int ) ) );
+  connect( m_previewer,       TQ_SIGNAL( state( int ) ),
+           this,              TQ_SLOT( slotSetSynchronizerState( int ) ) );
 
-  connect( kapp,              TQT_SIGNAL( shutDown() ),
-           this,              TQT_SLOT( slotShutdown() ) );
+  connect( kapp,              TQ_SIGNAL( shutDown() ),
+           this,              TQ_SLOT( slotShutdown() ) );
 }
 
 
@@ -904,7 +904,7 @@ void Smb4KCore::setDefaultSettings()
 
 
 /////////////////////////////////////////////////////////////////////////////
-//  TQT_SLOT IMPLEMENTATIONS
+//  SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
 
 void Smb4KCore::slotSetScannerState( int state )
