@@ -98,10 +98,10 @@ const TQString Smb4KHomesSharesHandler::specifyUser( const TQString &host, TQWid
   layout->addMultiCellWidget( userCombo, 1, 1, 1, 4, 0 );
   layout->addItem( spacer1, 0, 2 );
 
-  connect( userCombo, TQT_SIGNAL( textChanged( const TQString &) ),
-           this,      TQT_SLOT( slotTextChanged( const TQString & ) ) );
-  connect( m_dlg,     TQT_SIGNAL( user1Clicked() ),
-           this,      TQT_SLOT( slotClearClicked() ) );
+  connect( userCombo, TQ_SIGNAL( textChanged( const TQString &) ),
+           this,      TQ_SLOT( slotTextChanged( const TQString & ) ) );
+  connect( m_dlg,     TQ_SIGNAL( user1Clicked() ),
+           this,      TQ_SLOT( slotClearClicked() ) );
 
   // Read the list of logins, that are already defined
   // for this 'homes' share.
@@ -325,7 +325,7 @@ void Smb4KHomesSharesHandler::write_names( const TQString &host, const TQStringL
 
 
 /////////////////////////////////////////////////////////////////////////////
-// TQT_SLOT IMPLEMENTATIONS
+// SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
 
 void Smb4KHomesSharesHandler::slotTextChanged( const TQString &text )
