@@ -63,17 +63,17 @@ Smb4KSynchronizer::Smb4KSynchronizer( TQObject *parent, const char *name )
 
   m_working = false;
 
-  connect( m_proc, TQT_SIGNAL( receivedStdout( TDEProcess *, char *, int ) ),
-           this,   TQT_SLOT( slotReceivedStdout( TDEProcess *, char *, int ) ) );
+  connect( m_proc, TQ_SIGNAL( receivedStdout( TDEProcess *, char *, int ) ),
+           this,   TQ_SLOT( slotReceivedStdout( TDEProcess *, char *, int ) ) );
 
-  connect( m_proc, TQT_SIGNAL( processExited( TDEProcess* ) ),
-           this,   TQT_SLOT( slotProcessExited( TDEProcess * ) ) );
+  connect( m_proc, TQ_SIGNAL( processExited( TDEProcess* ) ),
+           this,   TQ_SLOT( slotProcessExited( TDEProcess * ) ) );
 
-  connect( m_proc, TQT_SIGNAL( receivedStderr( TDEProcess *, char *, int ) ),
-           this,   TQT_SLOT( slotReceivedStderr( TDEProcess *, char *, int ) ) );
+  connect( m_proc, TQ_SIGNAL( receivedStderr( TDEProcess *, char *, int ) ),
+           this,   TQ_SLOT( slotReceivedStderr( TDEProcess *, char *, int ) ) );
 
-  connect( kapp,   TQT_SIGNAL( shutDown() ),
-           this,   TQT_SLOT( slotShutdown() ) );
+  connect( kapp,   TQ_SIGNAL( shutDown() ),
+           this,   TQ_SLOT( slotShutdown() ) );
 }
 
 
@@ -356,7 +356,7 @@ const TQString Smb4KSynchronizer::readRsyncOptions()
 
 
 /////////////////////////////////////////////////////////////////////////////
-//   TQT_SLOT IMPLEMENTATIONS
+//   SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
 
 void Smb4KSynchronizer::abort()
