@@ -63,17 +63,17 @@ Smb4KFileIO::Smb4KFileIO( TQObject *parent, const char *name ) : TQObject( paren
   m_proc = new TDEProcess( this, "FileIOProcess" );
   m_proc->setUseShell( true );
 
-  connect( m_proc, TQT_SIGNAL( receivedStderr( TDEProcess *, char *, int ) ),
-           this,   TQT_SLOT( slotReceivedStderr( TDEProcess *, char *, int ) ) );
+  connect( m_proc, TQ_SIGNAL( receivedStderr( TDEProcess *, char *, int ) ),
+           this,   TQ_SLOT( slotReceivedStderr( TDEProcess *, char *, int ) ) );
 
-  connect( m_proc, TQT_SIGNAL( receivedStdout( TDEProcess *, char *, int ) ),
-           this,   TQT_SLOT( slotReceivedStdout( TDEProcess *, char *, int ) ) );
+  connect( m_proc, TQ_SIGNAL( receivedStdout( TDEProcess *, char *, int ) ),
+           this,   TQ_SLOT( slotReceivedStdout( TDEProcess *, char *, int ) ) );
 
-  connect( m_proc, TQT_SIGNAL( processExited( TDEProcess * ) ),
-           this,   TQT_SLOT( slotProcessExited( TDEProcess * ) ) );
+  connect( m_proc, TQ_SIGNAL( processExited( TDEProcess * ) ),
+           this,   TQ_SLOT( slotProcessExited( TDEProcess * ) ) );
 
-  connect( kapp,   TQT_SIGNAL( shutDown() ),
-           this,   TQT_SLOT( slotShutdown() ) );
+  connect( kapp,   TQ_SIGNAL( shutDown() ),
+           this,   TQ_SLOT( slotShutdown() ) );
 }
 
 
@@ -1695,7 +1695,7 @@ void Smb4KFileIO::processSuperTab()
 }
 
 /////////////////////////////////////////////////////////////////////////////
-// TQT_SLOT IMPLEMENTATIONS
+// SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
 
 void Smb4KFileIO::slotShutdown()
