@@ -262,14 +262,14 @@ void Smb4KCustomOptionsDialog::setupDialog()
       }
 
       // Connections:
-      connect( m_port_input,  TQT_SIGNAL( valueChanged( int ) ),
-               this,          TQT_SLOT( slotPortChanged( int ) ) );
+      connect( m_port_input,  TQ_SIGNAL( valueChanged( int ) ),
+               this,          TQ_SLOT( slotPortChanged( int ) ) );
 
-      connect( m_kerberos,    TQT_SIGNAL( toggled( bool ) ),
-               this,          TQT_SLOT( slotKerberosToggled( bool ) ) );
+      connect( m_kerberos,    TQ_SIGNAL( toggled( bool ) ),
+               this,          TQ_SLOT( slotKerberosToggled( bool ) ) );
 
-      connect( m_proto_input, TQT_SIGNAL( activated( const TQString & ) ),
-               this,          TQT_SLOT( slotProtocolChanged( const TQString & ) ) );
+      connect( m_proto_input, TQ_SIGNAL( activated( const TQString & ) ),
+               this,          TQ_SLOT( slotProtocolChanged( const TQString & ) ) );
 
       break;
     }
@@ -448,24 +448,24 @@ void Smb4KCustomOptionsDialog::setupDialog()
 #endif
 
       // Connections:
-      connect( m_port_input,  TQT_SIGNAL( valueChanged( int ) ),
-               this,          TQT_SLOT( slotPortChanged( int ) ) );
+      connect( m_port_input,  TQ_SIGNAL( valueChanged( int ) ),
+               this,          TQ_SLOT( slotPortChanged( int ) ) );
 
-      connect( m_uid_input,   TQT_SIGNAL( textChanged( const TQString & ) ),
-               this,          TQT_SLOT( slotUIDChanged( const TQString & ) ) );
+      connect( m_uid_input,   TQ_SIGNAL( textChanged( const TQString & ) ),
+               this,          TQ_SLOT( slotUIDChanged( const TQString & ) ) );
 
-      connect( m_gid_input,   TQT_SIGNAL( textChanged( const TQString & ) ),
-               this,          TQT_SLOT( slotGIDChanged( const TQString & ) ) );
+      connect( m_gid_input,   TQ_SIGNAL( textChanged( const TQString & ) ),
+               this,          TQ_SLOT( slotGIDChanged( const TQString & ) ) );
 
 #ifndef __FreeBSD__
-      connect( m_kerberos,    TQT_SIGNAL( toggled( bool ) ),
-               this,          TQT_SLOT( slotKerberosToggled( bool ) ) );
+      connect( m_kerberos,    TQ_SIGNAL( toggled( bool ) ),
+               this,          TQ_SLOT( slotKerberosToggled( bool ) ) );
 
-      connect( m_rw_input,    TQT_SIGNAL( activated( const TQString & ) ),
-               this,          TQT_SLOT( slotWriteAccessChanged( const TQString & ) ) );
+      connect( m_rw_input,    TQ_SIGNAL( activated( const TQString & ) ),
+               this,          TQ_SLOT( slotWriteAccessChanged( const TQString & ) ) );
 
-      connect( m_fs_input,    TQT_SIGNAL( activated( const TQString & ) ),
-               this,          TQT_SLOT( slotFilesystemChanged( const TQString & ) ) );
+      connect( m_fs_input,    TQ_SIGNAL( activated( const TQString & ) ),
+               this,          TQ_SLOT( slotFilesystemChanged( const TQString & ) ) );
 #endif
 
       break;
@@ -482,17 +482,17 @@ void Smb4KCustomOptionsDialog::setupDialog()
   enableButton( User1, enable_default_button );
 
   // Connect the buttons:
-  connect( this,          TQT_SIGNAL( okClicked() ),
-           this,          TQT_SLOT( slotOKButtonClicked() ) );
+  connect( this,          TQ_SIGNAL( okClicked() ),
+           this,          TQ_SLOT( slotOKButtonClicked() ) );
 
-  connect( this,          TQT_SIGNAL( user1Clicked() ),
-           this,          TQT_SLOT( slotDefaultButtonClicked() ) );
+  connect( this,          TQ_SIGNAL( user1Clicked() ),
+           this,          TQ_SLOT( slotDefaultButtonClicked() ) );
 
   setFixedSize( (sizeHint().width() > 350 ? sizeHint().width() : 350), sizeHint().height() );
 }
 
 /////////////////////////////////////////////////////////////////////////////
-// TQT_SLOT IMPLEMENTATIONS
+// SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
 
 void Smb4KCustomOptionsDialog::slotPortChanged( int val )
