@@ -64,17 +64,17 @@ Smb4KPreviewDialog::Smb4KPreviewDialog( Smb4KShareItem *item, TQWidget *parent,
 
     setInitialSize( configDialogSize( *(Smb4KSettings::self()->config()), "PreviewDialog" ) );
 
-    connect( m_view,                 TQT_SIGNAL( executed( TQIconViewItem * ) ),
-            this,                    TQT_SLOT( slotItemExecuted( TQIconViewItem * ) ) );
+    connect( m_view,                 TQ_SIGNAL( executed( TQIconViewItem * ) ),
+            this,                    TQ_SLOT( slotItemExecuted( TQIconViewItem * ) ) );
 
-    connect( m_toolbar,              TQT_SIGNAL( clicked( int ) ),
-            this,                    TQT_SLOT( slotButtonClicked( int ) ) );
+    connect( m_toolbar,              TQ_SIGNAL( clicked( int ) ),
+            this,                    TQ_SLOT( slotButtonClicked( int ) ) );
 
-    connect( m_combo,                TQT_SIGNAL( activated( const TQString & ) ),
-            this,                    TQT_SLOT( slotItemActivated( const TQString & ) ) );
+    connect( m_combo,                TQ_SIGNAL( activated( const TQString & ) ),
+            this,                    TQ_SLOT( slotItemActivated( const TQString & ) ) );
 
-    connect( Smb4KCore::previewer(), TQT_SIGNAL( result( Smb4KPreviewItem * ) ),
-             this,                   TQT_SLOT( slotReceivedData( Smb4KPreviewItem * ) ) );
+    connect( Smb4KCore::previewer(), TQ_SIGNAL( result( Smb4KPreviewItem * ) ),
+             this,                   TQ_SLOT( slotReceivedData( Smb4KPreviewItem * ) ) );
 
     m_initialized = Smb4KCore::previewer()->preview( m_item );
   }
@@ -124,7 +124,7 @@ void Smb4KPreviewDialog::setupView()
 
 
 /////////////////////////////////////////////////////////////////////////////
-// TQT_SLOT IMPLEMENTATIONS
+// SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
 
 void Smb4KPreviewDialog::slotReceivedData( Smb4KPreviewItem *item )
