@@ -31,7 +31,7 @@
 #endif
 
 // KDE includes
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include <kdialogbase.h>
 #include <kurlrequester.h>
 
@@ -47,7 +47,7 @@ class Smb4KSynchronizationInfo;
  * @author Alexander Reinholdt <dustpuppy@users.berlios.de>
  */
 
-class KDE_EXPORT Smb4KSynchronizationDialog : public KDialogBase
+class TDE_EXPORT Smb4KSynchronizationDialog : public KDialogBase
 {
   TQ_OBJECT
   
