@@ -55,8 +55,8 @@ Smb4KSharesIconView::Smb4KSharesIconView( TQWidget *parent, const char *name )
   m_tooltip = NULL;
 
   // Connections:
-  connect( this, TQT_SIGNAL( pressed( TQIconViewItem * ) ),
-           this, TQT_SLOT( slotPressed( TQIconViewItem * ) ) );
+  connect( this, TQ_SIGNAL( pressed( TQIconViewItem * ) ),
+           this, TQ_SLOT( slotPressed( TQIconViewItem * ) ) );
 }
 
 
@@ -150,7 +150,7 @@ void Smb4KSharesIconView::contentsDropEvent( TQDropEvent *e )
   {
     if ( dest.equals( *it, true ) )
     {
-      if ( e->source() == this || TQT_BASE_OBJECT(e->source()->parent()) == TQT_BASE_OBJECT(this) )
+      if ( e->source() == this || e->source()->parent() == this )
       {
         e->ignore();
 
@@ -187,7 +187,7 @@ void Smb4KSharesIconView::contentsMouseMoveEvent( TQMouseEvent *e )
         {
           m_tooltip = new Smb4KSharesIconViewToolTip( item );
 
-          TQTimer::singleShot( 2000, this, TQT_SLOT( slotShowToolTip() ) );
+          TQTimer::singleShot( 2000, this, TQ_SLOT( slotShowToolTip() ) );
         }
         else
         {
@@ -207,7 +207,7 @@ void Smb4KSharesIconView::contentsMouseMoveEvent( TQMouseEvent *e )
       {
         m_tooltip = new Smb4KSharesIconViewToolTip( item );
 
-        TQTimer::singleShot( 2000, this, TQT_SLOT( slotShowToolTip() ) );
+        TQTimer::singleShot( 2000, this, TQ_SLOT( slotShowToolTip() ) );
       }
       else
       {
@@ -229,7 +229,7 @@ void Smb4KSharesIconView::contentsMouseMoveEvent( TQMouseEvent *e )
 
 
 /////////////////////////////////////////////////////////////////////////////
-// TQT_SLOT IMPLEMENTATIONS
+// SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
 
 void Smb4KSharesIconView::slotPressed( TQIconViewItem *item )
