@@ -47,7 +47,7 @@
 
 class Smb4KSharesIconViewPart : public KParts::Part
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
@@ -192,7 +192,7 @@ class TDEAboutData;
 
 class Smb4KSharesIconViewPartFactory : public KParts::Factory
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
