@@ -47,7 +47,7 @@
 
 class Smb4KSharesListViewPart : public KParts::Part
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
@@ -194,7 +194,7 @@ class TDEAboutData;
 
 class Smb4KSharesListViewPartFactory : public KParts::Factory
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
