@@ -47,7 +47,7 @@ class Smb4KSharesListViewItem;
 
 class Smb4KSharesListViewToolTip : public TQLabel
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
