@@ -30,7 +30,7 @@
 
 // KDE includes
 #include <tdeaboutdata.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kdebug.h>
 #include <kiconeffect.h>
 #include <kiconloader.h>
